package cn.iocoder.yudao.module.infra.api.file;

import cn.hutool.core.util.IdUtil;
import cn.iocoder.yudao.module.infra.api.file.dto.FileRespDto;

/**
 * 文件 API 接口
 *
 * @author 捷道源码
 */
public interface FileApi {

    /**
     * 保存文件，并返回文件的访问路径
     *
     * @param content 文件内容
     * @return 文件路径
     */
   default String createFile(byte[] content) throws Exception {
       return createFile(IdUtil.fastUUID(), content);
   }

    /**
     * 保存文件，并返回文件的访问路径
     *
     * @param path 文件路径
     * @param content 文件内容
     * @return 文件路径
     */
    String createFile(String path, byte[] content) throws Exception;

    /**
     * 保存文件，并返回文件的存储对象信息
     *
     * @param dir      目录 注意：目录以“/”结尾
     * @param fileName 文件名称 注意：文件名需要携带尾缀
     * @param content  文件内容
     * @return 文件路径
     */
    FileRespDto createFile(String dir, String fileName, byte[] content) throws Exception;



    /**
     * 删除文件
     *
     * @param id 编号
     */
    void deleteFile(Long id) throws Exception;


}
